@@ -3,6 +3,5 @@ var classcaellion_1_1pycommons_1_1codeanalysis_1_1reports_1_1_report_builder =
     [ "__init__", "classcaellion_1_1pycommons_1_1codeanalysis_1_1reports_1_1_report_builder.html#a9afdbf0df53e179cd1aa6d926d9133de", null ],
     [ "addIssue", "classcaellion_1_1pycommons_1_1codeanalysis_1_1reports_1_1_report_builder.html#a147a627595bb0cfa5bddfd0cb92af581", null ],
     [ "extract_basename_file", "classcaellion_1_1pycommons_1_1codeanalysis_1_1reports_1_1_report_builder.html#a80827beb00309a8ec2a4db00f987145a", null ],
-    [ "generateReport", "classcaellion_1_1pycommons_1_1codeanalysis_1_1reports_1_1_report_builder.html#ac982ec9943e26a884014603a561acf81", null ],
-    [ "issues_all", "classcaellion_1_1pycommons_1_1codeanalysis_1_1reports_1_1_report_builder.html#a633b5b3289f005ca5260c43aa50aee14", null ]
+    [ "generateReport", "classcaellion_1_1pycommons_1_1codeanalysis_1_1reports_1_1_report_builder.html#ac982ec9943e26a884014603a561acf81", null ]
 ];
\ No newline at end of file
