@@ -3,6 +3,8 @@ var namespaces =
     [ "caellion", "namespacecaellion.html", "namespacecaellion" ],
     [ "parse-tests", "namespaceparse-tests.html", null ],
     [ "test_codeanalysis_reports", "namespacetest__codeanalysis__reports.html", null ],
+    [ "test_encryption_tripledes", "namespacetest__encryption__tripledes.html", null ],
+    [ "test_serializers_datetime_serializer", "namespacetest__serializers__datetime__serializer.html", null ],
     [ "test_stringutil_formatters", "namespacetest__stringutil__formatters.html", null ],
     [ "version-check", "namespaceversion-check.html", null ]
 ];
\ No newline at end of file
