@@ -1,10 +1,10 @@
 var indexSectionsWithContent =
 {
-  0: "_abcdefgiklmnprstvx",
-  1: "inrt",
+  0: "_abcdefgiklmnprstuvx",
+  1: "dinrt",
   2: "cptv",
-  3: "_fprtv",
-  4: "_aefgt",
+  3: "_dfprtv",
+  4: "_adefgstu",
   5: "abcdefiklmnprstvx",
   6: "c"
 };
